function soon_cadence, textfile, giffile=giffile, debug=debug
;+
;   Name: soon_cadence
;
;   Purpose: read a soon_search output file and generate a plot file
;
;   Input Parameters:
;      textfile - output file (from pr_gsn)
;
;   Calling Sequence:
;      outplot=soon_cadence(filename)
; 
;   History:
;      10-jun-1996 S.L.Freeland
;-
; read the data
data=rd_tfile(textfile)
if not keyword_set(giffile) then $
   giffile=str_replace(str_replace(textfile,'.text','.gif'),'text_','img_')

soonsites=str2arr('Holloman,Learmonth,Ramey,San Vito')
colors=[2,5,7,9]

img=where(strpos(data,'IMAGE LISTING') ne -1,ilcnt)
ss=where(strpos(strtrim(strlowcase(data),2),'st') eq 0,sscnt)

if ilcnt eq 0 and sscnt eq 0 then begin
   message,/info,"No summary listing OR Image listing found..."
   return,-1
endif

case 1 of
   ilcnt eq 1: begin
      data=strtrim(data(img(0)+1:n_elements(data)-1),2)
      dss=(where(strpos(data,'Date') eq 0))(0)+2
      if dss lt n_elements(data)-dss then begin 
         data=data(dss:*)
	 times0=anytim2ints(strmid(data,0,19))
         order=sort(int2secarr(times0)) & times0=times0(order) 
         times1=times0
         site=strlowcase(strmids(data(order),strpos(strlowcase(data(order)),'st')+2,1))
         event_exe='events=times0(which)'

     endif else times0=''
     title='SOONSPOT Image Times'
   endcase

   sscnt gt 0: begin
      stable=strtrim(str2cols(data(ss),colpos=[74,93,97,120]),2)
      times0=anytim2ints(reform(stable(0,*)))
      times1=anytim2ints(reform(stable(2,*)))
      order=sort(int2secarr(times0)) & times0=times0(order) &  times1=times1(order)
      site=reform(strmid(strtrim(data(ss(order)),2),2,1))
      event_exe='events=[times0(which),times1(which)]'
      title='SOONSPOT File Times'
if keyword_set(debug) then stop,'table
    endcase
endcase
      
;  ------------- Now plot the results (uses Z buffer) ---------------
   ptemp=!d.name
   nt=n_elements(times0)
   wdef,xx,/zbuffer,800,350 &   set_plot,'z'
   erase
   linecolors
   utplot,[times0(0),times1(nt-1)],[100,100],/nodata, xmargin=[.05,.05], $
      yticklen=.005, ytickname= string(replicate(32b,6)), title=title,   $
      charsize=.7, background=11

   for i=0,n_elements(soonsites)-1 do begin
      which=where(strupcase(site) eq strupcase(strmid(soonsites(i),0,1)),sscnt)
      if sscnt gt 0 then begin
         exe=execute(event_exe)
         evt_grid, events, color=colors(i), tickpos=.7 - (i*.1), thick=2, $
            ticklen=.05
      endif
   endfor

   legend,soonsites,color=colors,position=[.2,.95],$
      psym=intarr(n_elements(soonsites))+2,/horiz,/normal
;  -------------------------------------------------------------

; - now write a gif file and restore plot device
zbuff2file,giffile,/gif
retval=tvrd()
set_plot,ptemp

return, retval
end

