pro soon_catstat, tapes, catfile, nfiles, tstart, tstop, $
   cataloged, status, generate=generate, text=text, display=display, $
   index=index
;+
;   Name: soon_catstat
;
;   Purpose: return SOONSPOT catalog status (or generate the status file)
;
;   Input Paramters:
;      NONE:
;
;   Output Paramters:
;     tape      - tapenames from soonspot checklist (read_sooncheck)
;     catfile   - corresponding catalog file ('' = none found)
;     nfiles    - number of files on tape (-1 = no catalog)
;     tstart    - start time of first record on tape
;     tstop     - stop time of last record
;     cataloged - catalog program run?
;
;   Keyword Paramters:
;      generate - if set, generate the status file (default reads/reports)
;
;   History:
;      13-Jun-1996 (S.L.Freeland)
;      18-jun-1996 (add status info)
;
;-
repfile=concat_dir('$DIR_SITE_LOGS','soon_catstat.dat')
generate=keyword_set(generate) or (1-file_exist(repfile))
display=keyword_set(display)
topdoc=concat_dir('$path_http','soon')

if generate then begin
   if display then begin
      ptemp=!d.name
      wdef,xx,/zbuffer,450,200
      set_plot,'z
      tvlct,ro,go,bo,/get
      linecolors
   endif
   read_sooncheck,tapes, cataloged	; tapenames and booleans
   nt=n_elements(tapes)
   cstatus=lonarr(nt)-1			; intial status
   catfile=strarr(nt) & tstart=catfile & tstop=catfile  ; initialize output
   nfiles=lonarr(nt)-1

   cnames='st'+strlowcase(strmid(tapes,0,7))+'.cat'	; derived name
   cfiles=concat_dir('$DIR_GSN_OBS',cnames)
   exist=file_exist(cfiles)

   catfound=where(exist,ecnt)
   catfile(catfound)=cfiles(catfound)
   resp=''
   for i=0, ecnt-1 do begin
      rd_gsn,cfiles(catfound(i)),fstr, fdata
      nf=n_elements(fstr)
      nd=n_elements(fdata)
      if nf gt 1 then fstr=sort_index(fstr)
      nfiles(catfound(i))=nf
      tstartx=fmt_tim(fstr(0))
      tstopx=timegrid(fstr(nf-1),sec=fstr(nf-1).duration,/string)
      tstart(catfound(i))=tstartx
      tstop(catfound(i))=tstopx
      deltat=ssw_deltat(tstartx,tstopx,/day)
      dtfile=0
      dtdata=0
      if nd gt 1 then dtdata=max(deriv_arr(int2secarr(fdata)))
      if nf gt 1 then dtfile=max(deriv_arr(int2secarr(fstr)))
      
;     build status word

      status=0l
      wdelta=deltat gt 24 or deltat lt 3
      status=status or (wdelta*1)		; bit 0 = deltaT count
      status=status or ((nf le 5)*2)		; bit 1 = low file count
      status=status or ((nd le 20)*4)		; bit 2 = low image count
      status=status or (((dtfile eq 0) or (dtfile gt 86400l*5))*8)
      status=status or (((dtdata eq 0) or (dtfile gt 86400l*5))*16)
      cstatus(catfound(i))=status

      info=strjustify(['Catalog',cnames(catfound(i))],/cent) 	+ '  ' + $
	   strjustify(['Nfiles',strtrim(nf,2)],/cent)		+ '  ' + $
	   strjustify(['NImages',strtrim(nd,2)],/cent)	+ '  ' + $
           strjustify(['DeltaT',string(deltat,format='(f5.1, " days")')],/cen) + '  ' + $
           strjustify(['Status',(['OK','??'])(status ne 0)],/center)

      if display then begin
        set_plot,'z
        erase
        dtd=[-1,1]
        if deltat lt 2 then dtd=[-3,3]
        range=[timegrid(tstartx,day=dtd(0),/string),$
               timegrid( tstopx,day=dtd(1),/string)]

        utplot, fstr, [0,10], /nodata, ystyle=1,xmargin=[.2,.2], $
		timerange=range,charsize=.7,yticklen=.001, $
                title='SOONSPOT CADENCE for ' + cnames(catfound(i)),back=11
        evt_grid,timegrid(tstartx,day=deltat/2.), $
           label='-- DeltaT = ' + string(deltat,format='(f6.2)') + ' Days --', color=3, $
	   tickpos=.2, labpos=.2, labcolor=9
        evt_grid,tstart(catfound(i)),label=string(tstartx),color=2,linestyle=0, align=0,labpos=.4,labsize=.7
        evt_grid,tstop(catfound(i)),label=string(tstopx),color=2,linestyle=0, /align,labpos=.35,labsize=.7
        evt_grid,fstr,color=5,tickpos=.75,ticklen=.1
        evt_grid,tstopx,color=5,tickpos=.75,ticklen=.1,label=' <File Times',align=0, $
          labcol=5,labsize=.7,/noarr
        evt_grid,fdata, color=7, tickpos=.55,ticklen=.1
        evt_grid,tstopx,color=7,tickpos=.55,ticklen=.1,label=' <Image Times',align=0, $
           labcol=7,labsiz=.7,/noarr
        gfile=concat_dir(topdoc,str_replace(cnames(catfound(i)),'.cat','.gif'))
        hfile=concat_dir(topdoc,str_replace(cnames(catfound(i)),'.cat','.html'))
        zbuff2file,gfile
;       ------------- make a WWW document -----------
        sxt_html,hfile,/header
        file_append,hfile,$
          '<h2>SOONSPOT Catalog status for: ' +  cnames(catfound(i)) + '</h2>'
        file_append,hfile,[strtab2html(info,/row0header)]
        file_append,hfile,['<p><center><b>Cadence Plot</b></center', $
             '<center><img src="' + http_names(gfile) + '"></center>']
        file_append,hfile,$
           [str2html(concat_dir(http_names(topdoc),'soonspot_status.html'), $
               link_text="Back to SOONSPOT Status Index"),'<p><p>']
        sxt_html,hfile,/trailer
        set_plot,ptemp
      endif
   endfor

;  make report array and write to file
   pr_status,txt,caller='soon_catstat',/idlcomment
   text  =strjustify([';TapeName','',tapes])           		+ ' ' + $
          strjustify(['Catalog','',cnames])            		+ ' ' + $
          strjustify(['NFils','',strtrim(nfiles,2)],/center)	+ ' ' + $
          strjustify(['First Time','',tstart],/center) 		+ ' ' + $
          strjustify(['Last Time','',tstop],/center) 	       	+ ' ' + $
	  strjustify(['CatRun?','',strtrim(fix(cataloged),2)],/center) + ' ' + $
	  strjustify(['Status','',strtrim(cstatus,2)],/center) 

   file_append, repfile, [txt,text],/new		
   soon_com2html					; add comments 2 html

endif else begin					   
   text=rd_tfile(repfile,nocom=';')		      	; read the ascii
   cols=str2cols(text)				      	; convert to table
   cols(3,*)=cols(3,*) + ' ' + cols(4,*) & cols(4,*)='' ; combine t0 day/time
   cols(5,*)=cols(5,*) + ' ' + cols(6,*) & cols(6,*)='' ; combine t1 day/time 
   cols=strarrcompress(cols,/columns)			; eliminate null columns
   params=str2arr('tapes, catfile, nfiles, tstart, tstop, cataloged, status') 
   for i=0,n_elements(params)-1 do $
      exe=execute(params(i) + '=reform(cols(i,*))')   
   ; make a WWW index

   if keyword_set(index) then begin
      ifile=concat_dir(topdoc,'soonspot_status.html')
      sxt_html,/header,ifile
      file_append,ifile,'<h2>SOONSPOT Catalog Status</h2>'
      sites=str2arr('holloman,learmonth,ramey,san vito')
      capsites=strcapitalize(sites)
      for site=0,n_elements(sites)-1 do begin
         sssite=where(strmid(capsites(site),0,1) eq strmid(reform(cols(0,*)),0,1))
         nrows=n_elements(cols(0,sssite))
         links=strarr(nrows)
         status=reform(fix(cols(6,sssite)))
         ss=where(status ge 0,sscnt)
         ssok=where(status eq 0,gcnt)
         ssbad=where(status gt 0, bcnt)
         ssno=where(status eq -1,ncnt)
         if gcnt gt 0 then $
           cols(6,sssite(ssok)) = 'OK'   ; cols(6,sssite(ssok))  + '(OK)'         
         if bcnt gt 0 then $
           cols(6,sssite(ssbad)) = '??'  ; cols(6,sssite(ssbad)) + '(Prob?)'         
         if ncnt gt 0 then $
           cols(6,sssite(ssno)) = 'NONE' ;cols(6,sssite(ssno)) + '(None)'         
         
         links(ss)=concat_dir(http_names(topdoc),$
            str_replace(reform(strtrim(cols(1,sssite(ss)),2)),'.cat','.html') )
         links(ss)=str2html(links(ss),link_text="cat html")
         table=[[cols(*,sssite)],transpose(links)]	; add a link column
         table=[[strcapitalize(params),'Info'],[table]]
         table(1,*)=''
         table=strarrcompress(table,/column)
         file_append,ifile,['<h2>' + capsites(site) + '</h2>', $
             strtab2html(table,/row0header),'<hr><p>']
      endfor
      sxt_html,/trailer,ifile
   endif
endelse

if display then begin
   set_plot,ptemp
   tvlct,ro,go,bo
endif

return
end

