function sooncat_cadence, t0, t1,  giffile=giffile
;+
;   Name: sooncat_cadence
;
;   Purpose: plot SOONSPOT catalog cadennce information
;
;   Input Parameters:
;      t0, t1 - time range of interest
;
;   Calling Sequence:
;      outplot=sooncat_cadence(t0,t1)
; 
;   Side Effects:
;      "clobbers" color table (linecolors called)
;
;   History:
;      10-jun-1996 S.L.Freeland
;-
if n_params() ne 2 then begin
   message,/info,"Need start time and start time
   return,0
endif

prefix=str2arr('h,l,r,s')
soonsites=soon_tapeinfo(prefix,/site)	; convert to names

;  ------------- plot the results (uses Z buffer) ---------------
   ptemp=!d.name
   nt=n_elements(times0)
   wdef,xx,/zbuffer,1024,512 &   set_plot,'z'
   linecolors
   colors=[2,5,7,9]
   labcols=shift(colors,-1)
   labcols=replicate(11,4)
;  set up the plot
   utplot,[t0,t1],[100,100],/nodata, xmargin=[.05,.05], color=0, $
      yticklen=.005, ytickname= string(replicate(32b,6)),  $
      charsize=.7,  title='SOONSPOT Catalog Cadence' ,background=230

;  ----------- read the tapenames and 'tape start' times --------------
   read_sooncheck, tapenames,cataloged			
   nocat=where(1-cataloged,nccnt)
   ttimes=soon_tapeinfo(tapenames,/times)
   tsites=soon_tapeinfo(tapenames,/site)
   inrange=sel_timrange(ttimes,t0,t1,/between)		; tapes in range...
   ; highlight tapes which have NOT been cataloged
   if nccnt gt 0 then tapenames(nocat)='*'+ tapenames(nocat) + '*'

;  -------------- soonsite loop -------------------------
   for i=0,n_elements(soonsites)-1 do begin
      gsnfiles=file_seltime(get_logenv('DIR_GSN_OBS'),'st'+prefix(i), t0,t1,/last_before)
      if gsnfiles(0) ne '' then begin
         rd_gsn, gsnfiles, filestr
         if data_chk(filestr,/struct) then $
            evt_grid, filestr, color=colors(i), tickpos=.72 - (i*.21), thick=2, $
               ticklen=.03
       endif
       twhich=where(tsites eq soonsites(i),wcnt)
       if wcnt gt 0 then evt_grid,ttimes(twhich),color=labcols(i), $
	   label='!3' + tapenames(twhich),/vertical, labpos=.82 - (i*.21), $
           /quiet,ticklen=.03, labsize=1, tickpos=.72 - (i*.21), labcol=labcols(i)
   endfor

;  add plot legend
!p.color=0
   legend,soonsites,color=colors,position=[.20,.97],$
      psym=intarr(n_elements(soonsites))+2,/horiz
!p.color=255
;  -------------------------------------------------------------

; return the plot
retval=tvrd()

; - write a gif file on request 
if keyword_set(giffile) then begin
   if not data_chk(giffile,/string) then gifffile='soonspot_cadence.gif'
   zbuff2file,giffile,/gif
endif

; restore plot device
set_plot,ptemp

return, retval
end

